Crate gf2poly

Crate gf2poly 

This rust crate provides a Gf2Poly type which implements polynomial arithmetic over GF(2). It links against the gf2x C library and care is taken to be asymptotically efficient. For example, multiplication is n log n (because the gf2x implementation is), and as a result, division can also be implemented in n log n. This crate also implements a fast gcd in n log² n time and a basic implementation of factorization. extern crate alloc;

Re-exports

pub use rand;

Structs

Gf2Poly
Gf2PolyMod
This type precalculates the factor for Barrett reduction, which can be used to speed up calculations using the same modulus. This takes a Borrow<Gf2Poly>, which can for example be a Gf2Poly, a &Gf2Poly or an Arc<Gf2Poly>.

Enums

Gf2PolyConversionError

Type Aliases

Limb